Name:           quota
Version:        4.10
Release:        %mkrel 1
Summary:        System administration tools for monitoring users' disk usage
License:        BSD and GPLv2+
Group:          System/Configuration
URL:            https://sourceforge.net/projects/linuxquota/
Source0:        https://prdownloads.sourceforge.net/linuxquota/%{name}-%{version}.tar.gz
Source1:        quota_nld.service
Source2:        quota_nld.sysconfig
Source3:        rpc-rquotad.service
Source4:        rpc-rquotad.sysconfig
Patch1:         quota-4.03-Validate-upper-bound-of-RPC-port.patch
Patch50:        quota-tools-default-conf.patch
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  e2fsprogs-devel
BuildRequires:  gettext-devel
BuildRequires:  pkgconfig(libnl-3.0)
BuildRequires:  openldap-devel
BuildRequires:  systemd
BuildRequires:  tcp_wrappers-devel
BuildRequires:  rpcgen
BuildRequires:  pkgconfig(libtirpc)
Requires:       quota-nls = %{version}-%{release}

%description
The quota package contains system administration tools for monitoring
and limiting user and or group disk usage per file system.

%package nld
Group:          System/Configuration
Summary:        quota_nld daemon
Requires:       quota-nls = %{version}-%{release}
Requires(post):     systemd
Requires(preun):    systemd

%description    nld
Daemon that listens on netlink socket and processes received quota warnings.
Note, that you have to enable the kernel support for sending quota messages
over netlink (in Filesystems->Quota menu). The daemon supports forwarding
warning messages to the system D-Bus (so that desktop manager can display
a dialog) and writing them to the terminal user has last accessed.

%package rpc
Summary:    RPC quota daemon
License:    BSD and LGPLv2+ and GPLv2 and GPLv2+
Requires:   quota-nls = %{version}-%{release}
Requires:   rpcbind
Requires:   tcp_wrappers
Requires(post):     systemd
Requires(preun):    systemd
Conflicts:  quota < 4.04-2

%description rpc
The RPC daemon allows to query and set disk quotas over network. If you run
the daemon on NFS server, you could use quota tools to manage the quotas from
NFS client.

%package        warnquota
Group:          System/Configuration
Summary:        Send e-mail to users over quota
Requires:       quota-nls = %{version}-%{release}

%description    warnquota
Utility that checks disk quota for each local file system and mails a warning
message to those users who have reached their soft limit.  It is typically run
via cron(8).

%package nls
Summary:    Gettext catalogs for disk quota tools
License:    BSD and LGPLv2+ and GPLv2 and GPLv2+
BuildArch:  noarch
Conflicts:  quota < 4.04-2

%description nls
Disk quota tools messages translated into different natural languages.

%package        devel
Group:          System/Configuration
Summary:        Development files for quota
Requires:       quota = %{version}-%{release}

%description    devel
The quota package contains system administration tools for monitoring
and limiting user and or group disk usage per file system.

This package contains development header files for implementing quotas
on remote machines.


%package        doc
Group:          Documentation
Summary:        Additional documentation for disk quotas
Requires:       quota >= %{version}-%{release}
BuildArch:      noarch

%description    doc
This package contains additional documentation for disk quotas concept in
Linux/UNIX environment.

%prep
%setup -q
%autopatch -p1

# Fix for perm bug #3053
chmod 755 ldap-scripts/setquota-ldap.pl

%build
%serverbuild

autoreconf -fi

%configure \
    --enable-bsd-behaviour \
    --enable-ext2direct \
    --enable-ldapmail \
    --enable-libwrap \
    --enable-netlink \
    --enable-nls \
    --disable-rpath \
    --enable-rpc=yes \
    --enable-rpcsetquota \
    --disable-silent-rules \
    --disable-xfs-roothack

%make_build

%install
%make_install
rm -rf %{buildroot}%{_docdir}/%{name}

install -m0644 warnquota.conf %{buildroot}%{_sysconfdir}

install -p -m644 -D %{SOURCE1} %{buildroot}%{_unitdir}/quota_nld.service
install -p -m644 -D %{SOURCE2} \
    %{buildroot}%{_sysconfdir}/sysconfig/quota_nld
install -p -m644 -D %{SOURCE3} %{buildroot}%{_unitdir}/rpc-rquotad.service
install -p -m644 -D %{SOURCE4} \
    %{buildroot}%{_sysconfdir}/sysconfig/rpc-rquotad

# we don't support XFS yet
rm -f %{buildroot}%{_sbindir}/quot
rm -f %{buildroot}%{_sbindir}/xqmstats
rm -f %{buildroot}%{_mandir}/man8/quot.*
rm -f %{buildroot}%{_mandir}/man8/xqmstats.*

%find_lang %{name}

%check
%__make check

%post nld
%_post_service quota_nld

%preun nld
%_preun_service quota_nld

%post rpc
%_post_service rpc-rquotad

%preun rpc
%_preun_service rpc-rquotad

%files
%{_bindir}/quota
%{_bindir}/quotasync
%{_sbindir}/convertquota
%{_sbindir}/edquota
%{_sbindir}/quotacheck
%{_sbindir}/quotaoff
%{_sbindir}/quotaon
%{_sbindir}/quotastats
%{_sbindir}/repquota
%{_sbindir}/setquota
%{_mandir}/man1/quota.1*
%{_mandir}/man1/quotasync.1*
%{_mandir}/man8/convertquota.8*
%{_mandir}/man8/edquota.8*
%{_mandir}/man8/quotacheck.8*
%{_mandir}/man8/quotaoff.8*
%{_mandir}/man8/quotaon.8*
%{_mandir}/man8/quotastats.8*
%{_mandir}/man8/repquota.8*
%{_mandir}/man8/setquota.8*

%files nld
%config(noreplace) %{_sysconfdir}/sysconfig/quota_nld
%{_unitdir}/quota_nld.service
%{_sbindir}/quota_nld
%{_mandir}/man8/quota_nld.8*

%files rpc
%config(noreplace) %{_sysconfdir}/sysconfig/rpc-rquotad
%{_unitdir}/rpc-rquotad.service
%{_sbindir}/rpc.rquotad
%{_mandir}/man8/rpc.rquotad.8*

%files warnquota
%config(noreplace) %{_sysconfdir}/warnquota.conf
%config(noreplace) %{_sysconfdir}/quotagrpadmins
%config(noreplace) %{_sysconfdir}/quotatab
%{_sbindir}/warnquota
%{_mandir}/man5/quotagrpadmins.5*
%{_mandir}/man5/quotatab.5*
%{_mandir}/man5/warnquota.conf.5*
%{_mandir}/man8/warnquota.8*
%doc README.ldap-support README.mailserver

%files nls -f %{name}.lang
%doc COPYING Changelog

%files devel
%dir %{_includedir}/rpcsvc
%{_includedir}/rpcsvc/*
%{_mandir}/man3/*

%files doc
%doc doc/* ldap-scripts


%changelog
* Sun May 04 2025 daviddavid <daviddavid> 4.10-1.mga10
+ Revision: 2180878
- new version: 4.10

* Sat Oct 22 2022 ghibo <ghibo> 4.09-1.mga9
+ Revision: 1898365
- Update to release 4.09.
- Use pkgconfig(libnl-3.0) in BR (caught by rpmlint).

* Tue Mar 29 2022 umeabot <umeabot> 4.06-3.mga9
+ Revision: 1833521
- Mageia 9 Mass Rebuild

* Wed Nov 25 2020 tv <tv> 4.06-2.mga8
+ Revision: 1649232
- BR new rpcgen pkg for bulding with glibc-2.32

* Wed Nov 18 2020 luigiwalser <luigiwalser> 4.06-1.mga8
+ Revision: 1647218
- 4.06
- remove unnecessary warnquota patch
+ danf <danf>
- Switch URLs from http: to https:

* Sun Feb 16 2020 umeabot <umeabot> 4.05-2.mga8
+ Revision: 1536684
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Oct 22 2019 zezinho <zezinho> 4.05-1.mga8
+ Revision: 1455127
- new upstream version 4.05

* Fri Feb 22 2019 daviddavid <daviddavid> 4.04-3.mga7
+ Revision: 1369344
- fix some dangling links

* Thu Sep 20 2018 guillomovitch <guillomovitch> 4.04-2.mga7
+ Revision: 1288778
- sync patch set with fedora
- split rpc part in an independant subpackage

* Thu Apr 19 2018 kekepower <kekepower> 4.04-1.mga7
+ Revision: 1220105
- Update to version 4.04
- Rediffed patches

* Sat Jan 23 2016 luigiwalser <luigiwalser> 4.03-2.mga6
+ Revision: 926675
- add rpc-rquotad.service that was dropped from nfs-utils (fedora)
- re-add ldap-scripts accidentally left out of upstream tarball
- sync fedora patches to make rquotad more secure and fix linking
- update configure arguments to make rquotad more secure
- enable make check (no-op for now)

* Sat Jan 02 2016 guillomovitch <guillomovitch> 4.03-1.mga6
+ Revision: 918072
- new version 4.03

* Thu Dec 25 2014 luigiwalser <luigiwalser> 4.02-1.mga5
+ Revision: 806030
- 4.02
- remove upstreamed patches
- re-order some lines in SPEC in accordance with fedora changes
- add patch from fedora to build with pie
- rediff patch 0 (from fedora)
- rediff patch 51
- BR systemd
- build with libnl3

* Wed Oct 15 2014 umeabot <umeabot> 4.01-4.mga5
+ Revision: 748205
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.01-3.mga5
+ Revision: 688586
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 4.01-2.mga4
+ Revision: 532653
- Mageia 4 Mass Rebuild

* Wed Aug 21 2013 luigiwalser <luigiwalser> 4.01-1.mga4
+ Revision: 469163
- 4.01 (sync with fedora)
- add libtirpc patch from omdv

* Wed Jan 23 2013 fwang <fwang> 3.17-10.mga3
+ Revision: 391517
- disable root sbin
- update rpm group

* Sun Jan 13 2013 umeabot <umeabot> 3.17-9.mga3
+ Revision: 380123
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Aug 30 2012 luigiwalser <luigiwalser> 3.17-8.mga3
+ Revision: 285908
- call autoheader/aclocal/autoconf (needed for patch 7)
- add patch from opensuse to fix CVE-2012-3417

* Fri Apr 20 2012 barjac <barjac> 3.17-7.mga2
+ Revision: 232036
- fixed bug 3053 doc file permissions
- cleaned spec

* Sun Jan 23 2011 ennael <ennael> 3.17-6.mga1
+ Revision: 33381
- imported package quota


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 3.17-6mdv2011.0
+ Revision: 607266
- rebuild

* Mon Mar 15 2010 Oden Eriksson <oeriksson@mandriva.com> 3.17-4mdv2010.1
+ Revision: 520206
- rebuilt for 2010.1

* Thu Sep 03 2009 Christophe Fergeau <cfergeau@mandriva.com> 3.17-3mdv2010.0
+ Revision: 426841
- rebuild

* Wed Feb 04 2009 Guillaume Rousse <guillomovitch@mandriva.org> 3.17-2mdv2009.1
+ Revision: 337607
- new release
- sync patch set with fedora
- keep bash completion in its own package
- rediff patch 1 (stripping)
- drop partches 5, 7 and 10, merged upstream

* Mon Dec 22 2008 Oden Eriksson <oeriksson@mandriva.com> 3.16-4mdv2009.1
+ Revision: 317559
- sync with quota-3.16-8.fc11.src.rpm

* Thu Sep 11 2008 Oden Eriksson <oeriksson@mandriva.com> 3.16-3mdv2009.0
+ Revision: 283788
- sync with quota-3.16-4.fc10.src.rpm

* Thu Aug 07 2008 Thierry Vignaud <tv@mandriva.org> 3.16-2mdv2009.0
+ Revision: 265615
- rebuild early 2009.0 package (before pixel changes)

* Tue Apr 15 2008 Guillaume Rousse <guillomovitch@mandriva.org> 3.16-1mdv2009.0
+ Revision: 194365
- new version
  drop patch 5 (merged upstream)
  drop patch 1 (makefile arg is enough)

* Thu Mar 06 2008 Oden Eriksson <oeriksson@mandriva.com> 3.15-1mdv2008.1
+ Revision: 180933
- sync with fc9

* Tue Jan 15 2008 Thierry Vignaud <tv@mandriva.org> 3.14-3mdv2008.1
+ Revision: 152810
- remove useless kernel require
- kill re-definition of %%buildroot on Pixel's request

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot


* Sun Jan 14 2007 Guillaume Rousse <guillomovitch@mandriva.org> 3.14-2mdv2007.0
+ Revision: 108839
- spec cleanup
- drop unused patches
- add bash completion

* Mon Dec 11 2006 Emmanuel Andry <eandry@mandriva.org> 3.14-1mdv2007.1
+ Revision: 94583
- New version 3.14
  bunzip patches
  drop patch 2
- Import quota

* Thu Jan 05 2006 Stefan van der Eijk <stefan@eijk.nu> 3.13-2mdk
- rebuild

* Wed Aug 10 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 3.13-1mdk
- 3.13
- fix summary-ended-with-dot
- %%mkrel

* Thu Nov 11 2004 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 3.12-1mdk
- 3.12
- sync with fedora

* Sun Aug 08 2004 Oden Eriksson <oeriksson@mandrakesoft.com> 3.10-1mdk
- 3.10
- synced with fedora
- misc spec file fixes

